/****************************************************************************/
/*	Copyright (c) 2009, Bendor Research Pty. Ltd. All rights reserved.		*/
/*	This software is released under the GNU General Public License, version	*/
/*	3, with the exemptions that 1) the header files installed by this 	 	*/
/*	package can be included in closed-source code and 2) the libraries		*/
/*	built by this package can be statically linked into a closed-source 	*/
/*	binary. See the file LICENSE for the details.							*/
/*	This software is provided "AS IS", without any warranty or guarantee.	*/
/*	By using this software you acknowledge that neither Bendor Research nor	*/
/*	any of its personnel or affiliates can be held liable for any damages,	*/
/*	including, but not limited to, loss of business, loss of money, loss of */
/*	life, loss of reputation, arising out of this software being faulty or	*/
/*	not performing as advertised, even if Bendor Research was aware of such	*/
/*	faults in the software. You use this software at your own risk, any and */
/*	all liabilities that arise out of your using this software are strictly	*/
/*	yours.																	*/
/****************************************************************************/

#include "kernel.h"

/****************************************************************************/
/*					Public API functions									*/
/****************************************************************************/

/** @addtogroup bx_time */
/** @{ */

/**
*	Sets the action of a timer.
*
*
*	@param	timer	Pointer to the timer object to be created.
*	@param	func	The soft interrupt function to call at expiry
*	@param	par1	The first argument of the soft interrupt function
*	@param	par2	The second argument of the soft interrupt function
*
*	@retval >0				Success
*	@retval	BX_ERR_OBJECT	The object is not a timer or wasn't initialised
*/

int		BX_TimerAction( BX_TIME *timer, BX_DISR_FUNC func,
					    void *par1, void *par2 )
{
int		cpsr;

	if ( timer->type != BX_TYPE_TIME )

		return( BX_ERR_OBJECT );

	cpsr = _bx_IrqDis();

	timer->func = func;
	timer->par1 = par1;
	timer->par2 = par2;

	_bx_IrqRes( cpsr );
	return( 1 );
}

/** @} */


